@@ -43,13 +43,28 @@ EFFECTIVE_FIREWALL_LIST_FORMAT = """\
     priority,
     action,
     direction,
+    disabled,
     ip_ranges.list():label=IP_RANGES
   )"""
+EFFECTIVE_SECURITY_POLICY_LIST_FORMAT = """\
+  table(
+    type,
+    security_policy_name,
+    priority,
+    action,
+    preview,
+    expression,
+    src_ip_ranges.list():label=SRC_IP_RANGES
+  )"""
 
 LIST_NOTICE = """\
 To show all fields of the firewall, please show in JSON format: --format=json
 To show more fields in table format, please see the examples in --help.
 """
+LIST_NOTICE_SECURITY_POLICY = """\
+To show all fields of the security policy, please show in JSON format: --format=json
+To show more fields in table format, please see the examples in --help.
+"""
 
 
 class ArgumentValidationError(exceptions.Error):
@@ -66,6 +81,7 @@ class ActionType(enum.Enum):
 
 
 def AddCommonArgs(parser,
+                  with_resource_manager_tags=False,
                   for_update=False,
                   with_egress_support=False,
                   with_service_account=False):
@@ -246,6 +262,16 @@ def AddCommonArgs(parser,
   if with_egress_support:
     AddArgsForEgress(parser, ruleset_parser, for_update)
 
+  if with_resource_manager_tags:
+    parser.add_argument(
+        '--resource-manager-tags',
+        type=arg_parsers.ArgDict(),
+        metavar='KEY=VALUE',
+        help="""\
+            A comma-separated list of Resource Manager tags to apply to the firewall.
+        """,
+    )
+
 
 def AddArgsForEgress(parser, ruleset_parser, for_update=False):
   """Adds arguments for egress firewall create or update subcommands."""
@@ -448,7 +474,9 @@ def SortOrgFirewallRules(client, rules):
       client.messages.SecurityPolicyRule.DirectionValueValuesEnum.EGRESS
   ]
   egress_org_firewall_rule.sort(key=lambda x: x.priority, reverse=False)
-  return ingress_org_firewall_rule + egress_org_firewall_rule
+  cloud_armor_rule = [item for item in rules if not item.direction]
+  cloud_armor_rule.sort(key=lambda x: x.priority, reverse=False)
+  return ingress_org_firewall_rule + egress_org_firewall_rule + cloud_armor_rule
 
 
 def SortFirewallPolicyRules(client, rules):
@@ -466,65 +494,85 @@ def SortFirewallPolicyRules(client, rules):
   return ingress_org_firewall_rule + egress_org_firewall_rule
 
 
-def ConvertFirewallPolicyRulesToEffectiveFwRules(
-    client,
-    firewall_policy,
-    support_network_firewall_policy,
-    support_region_network_firewall_policy=True):
+def ConvertFirewallPolicyRulesToEffectiveFwRules(client, firewall_policy):
   """Convert organization firewall policy rules to effective firewall rules."""
   result = []
   for rule in firewall_policy.rules:
-    item = {}
-    if (firewall_policy.type == client.messages
-        .NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy
-        .TypeValueValuesEnum.HIERARCHY or firewall_policy.type == client
-        .messages.InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
-        .TypeValueValuesEnum.HIERARCHY or
-        (support_region_network_firewall_policy and
-         firewall_policy.type == client.messages.
-         RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
-         .TypeValueValuesEnum.HIERARCHY)):
-      item.update({'type': 'org-firewall'})
-    elif support_network_firewall_policy and (
-        firewall_policy.type == client.messages
-        .NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy
-        .TypeValueValuesEnum.NETWORK or firewall_policy.type == client.messages
-        .InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
-        .TypeValueValuesEnum.NETWORK or
-        (support_region_network_firewall_policy and
-         firewall_policy.type == client.messages.
-         RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
-         .TypeValueValuesEnum.NETWORK)):
-      item.update({'type': 'network-firewall-policy'})
-    elif support_network_firewall_policy and (
-        firewall_policy.type == client.messages
-        .InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
-        .TypeValueValuesEnum.NETWORK_REGIONAL or
-        (support_region_network_firewall_policy and
-         firewall_policy.type == client.messages.
-         RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy
-         .TypeValueValuesEnum.NETWORK_REGIONAL)):
-      item.update({'type': 'network-regional-firewall-policy'})
-    else:
-      item.update({'type': 'unknown'})
-    item.update({'description': rule.description})
-    item.update({'firewall_policy_name': firewall_policy.name})
-    item.update({'priority': rule.priority})
-    item.update({'direction': rule.direction})
-    item.update({'action': rule.action.upper()})
-    item.update({'disabled': rule.disabled})
-    if rule.match.srcIpRanges:
-      item.update({'ip_ranges': rule.match.srcIpRanges})
-    if rule.match.destIpRanges:
-      item.update({'ip_ranges': rule.match.destIpRanges})
-    if rule.targetServiceAccounts:
-      item.update({'target_svc_acct': rule.targetServiceAccounts})
-    if rule.targetResources:
-      item.update({'target_resources': rule.targetResources})
+    item = ConvertFirewallPolicyRule(client, firewall_policy, rule)
+    item.update({'rule_type': 'FIREWALL_RULE'})
     result.append(item)
+
+  for rule in firewall_policy.packetMirroringRules:
+    item = ConvertFirewallPolicyRule(client, firewall_policy, rule)
+    item.update({'rule_type': 'PACKET_MIRRORING_RULE'})
+    result.append(item)
+
   return result
 
 
+def ConvertFirewallPolicyRule(client, firewall_policy, rule):
+  """Convert rule to effective firewall rule output."""
+  item = {}
+  if (
+      firewall_policy.type
+      == client.messages.NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy.TypeValueValuesEnum.HIERARCHY
+      or firewall_policy.type
+      == client.messages.InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy.TypeValueValuesEnum.HIERARCHY
+      or firewall_policy.type
+      == client.messages.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy.TypeValueValuesEnum.HIERARCHY
+  ):
+    item.update({'type': 'org-firewall'})
+  elif (
+      firewall_policy.type
+      == client.messages.NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy.TypeValueValuesEnum.NETWORK
+      or firewall_policy.type
+      == client.messages.InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy.TypeValueValuesEnum.NETWORK
+      or firewall_policy.type
+      == client.messages.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy.TypeValueValuesEnum.NETWORK
+  ):
+    item.update({'type': 'network-firewall-policy'})
+  elif (
+      firewall_policy.type
+      == client.messages.InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy.TypeValueValuesEnum.NETWORK_REGIONAL
+      or firewall_policy.type
+      == client.messages.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy.TypeValueValuesEnum.NETWORK_REGIONAL
+  ):
+    item.update({'type': 'network-regional-firewall-policy'})
+  elif (
+      firewall_policy.type
+      == client.messages.NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy.TypeValueValuesEnum.SYSTEM
+      or firewall_policy.type
+      == client.messages.InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy.TypeValueValuesEnum.SYSTEM_GLOBAL
+      or firewall_policy.type
+      == client.messages.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy.TypeValueValuesEnum.SYSTEM_GLOBAL
+  ):
+    item.update({'type': 'system-network-firewall-policy'})
+  elif (
+      firewall_policy.type
+      == client.messages.InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy.TypeValueValuesEnum.SYSTEM_REGIONAL
+      or firewall_policy.type
+      == client.messages.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy.TypeValueValuesEnum.SYSTEM_REGIONAL
+  ):
+    item.update({'type': 'system-network-regional-firewall-policy'})
+  else:
+    item.update({'type': 'unknown'})
+  item.update({'description': rule.description})
+  item.update({'firewall_policy_name': firewall_policy.name})
+  item.update({'priority': rule.priority})
+  item.update({'direction': rule.direction})
+  item.update({'action': rule.action.upper()})
+  item.update({'disabled': bool(rule.disabled)})
+  if rule.match.srcIpRanges:
+    item.update({'ip_ranges': rule.match.srcIpRanges})
+  if rule.match.destIpRanges:
+    item.update({'ip_ranges': rule.match.destIpRanges})
+  if rule.targetServiceAccounts:
+    item.update({'target_svc_acct': rule.targetServiceAccounts})
+  if rule.targetResources:
+    item.update({'target_resources': rule.targetResources})
+  return item
+
+
 def ConvertOrgSecurityPolicyRulesToEffectiveFwRules(security_policy):
   """Convert organization security policy rules to effective firewall rules."""
   result = []
@@ -581,3 +629,41 @@ def ConvertNetworkFirewallRulesToEffectiveFwRules(network_firewalls):
     item.update({'name': rule.name})
     result.append(item)
   return result
+
+
+def ConvertOrgSecurityPolicyRulesToEffectiveSpRules(security_policy):
+  """Convert org security policy rules to effective security policy rules."""
+  result = []
+  for rule in security_policy.rules:
+    item = {}
+    item.update({'type': 'org-security-policy'})
+    item.update({'description': rule.description})
+    item.update({'security_policy_name': security_policy.shortName})
+    item.update({'priority': rule.priority})
+    item.update({'action': rule.action.upper()})
+    item.update({'preview': rule.preview})
+    if rule.match.expr and rule.match.expr.expression:
+      item.update({'expression': rule.match.expr.expression})
+    if rule.match.config and rule.match.config.srcIpRanges:
+      item.update({'src_ip_ranges': rule.match.config.srcIpRanges})
+    result.append(item)
+  return result
+
+
+def ConvertSecurityPolicyRulesToEffectiveSpRules(security_policy):
+  """Convert security policy rules to effective security policy rules."""
+  result = []
+  for rule in security_policy.rules:
+    item = {}
+    item.update({'type': 'security-policy'})
+    item.update({'description': rule.description})
+    item.update({'security_policy_name': security_policy.name})
+    item.update({'priority': rule.priority})
+    item.update({'action': rule.action.upper()})
+    item.update({'preview': rule.preview})
+    if rule.match.expr and rule.match.expr.expression:
+      item.update({'expression': rule.match.expr.expression})
+    if rule.match.config and rule.match.config.srcIpRanges:
+      item.update({'src_ip_ranges': rule.match.config.srcIpRanges})
+    result.append(item)
+  return result
