@@ -25,7 +25,6 @@ import os
 from apitools.gen import gen_client
 from googlecloudsdk.api_lib.regen import api_def
 from googlecloudsdk.api_lib.regen import resource_generator
-from googlecloudsdk.api_lib.util import resource as resource_util
 from googlecloudsdk.core.util import files
 from mako import runtime
 from mako import template
@@ -59,10 +58,6 @@ class WrongDiscoveryDocError(Exception):
   """Unexpected discovery doc."""
 
 
-class UnsupportedDiscoveryDocError(Exception):
-  """Raised when some unsupported feature is detected."""
-
-
 def GenerateApitoolsApi(
     discovery_doc, output_dir, root_package, api_name, api_version, api_config):
   """Invokes apitools generator for given api."""
@@ -250,7 +245,6 @@ def GenerateApitoolsResourceModule(
       custom_resources: dict, dictionary of custom resource collections.
   Raises:
     WrongDiscoveryDocError: if discovery doc api name/version does not match.
-    UnsupportedDiscoveryDocError: if collections have different base URLs.
   """
 
   discovery_doc = resource_generator.DiscoveryDoc.FromJson(discovery_doc)
@@ -262,6 +256,11 @@ def GenerateApitoolsResourceModule(
   if discovery_doc.api_name != api_name:
     raise WrongDiscoveryDocError('api name {0}, expected {1}'.format(
         discovery_doc.api_name, api_name))
+  if discovery_doc.is_interface_versioned and not api_version.startswith('v_'):
+    raise WrongDiscoveryDocError(
+        '{0}/{1} API appears to be using interface-based versioning; version'
+        ' identifier {0} configured in gcloud_api_client_source target name and'
+        ' regen config should begin with "v_".'.format(api_name, api_version))
   resource_collections = discovery_doc.GetResourceCollections(
       custom_resources, api_version)
   if custom_resources:
@@ -304,19 +303,6 @@ def GenerateApitoolsResourceModule(
     logging.debug('Generating resource module at %s', resource_file_name)
     tpl = template.Template(filename=os.path.join(os.path.dirname(__file__),
                                                   'resources.tpl'))
-    url_api_version = resource_util.SplitEndpointUrl(
-        resource_collections[0].base_url)[1]
-    for c in resource_collections:
-      if url_api_version != resource_util.SplitEndpointUrl(c.base_url)[1]:
-        raise UnsupportedDiscoveryDocError(
-            'In client {0}/{1}, collection {2} is using url {3}, but '
-            'collection {4} is using url {5}'.format(
-                api_name,
-                api_version,
-                resource_collections[0].name,
-                resource_collections[0].base_url,
-                c.name,
-                c.base_url))
     with files.FileWriter(resource_file_name) as output_file:
       ctx = runtime.Context(output_file,
                             collections=sorted(resource_collections),
