@@ -18,9 +18,7 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import unicode_literals
 
-import copy
 import datetime
-import io
 import os.path
 import shutil
 import tarfile
@@ -31,9 +29,7 @@ from googlecloudsdk.api_lib.cloudbuild import snapshot
 from googlecloudsdk.api_lib.clouddeploy import client_util
 from googlecloudsdk.api_lib.clouddeploy import delivery_pipeline
 from googlecloudsdk.api_lib.storage import storage_api
-from googlecloudsdk.calliope import base
 from googlecloudsdk.calliope import exceptions as c_exceptions
-from googlecloudsdk.command_lib.code.cloud import cloudrun
 from googlecloudsdk.command_lib.deploy import deploy_util
 from googlecloudsdk.command_lib.deploy import exceptions
 from googlecloudsdk.command_lib.deploy import rollout_util
@@ -44,9 +40,7 @@ from googlecloudsdk.core import exceptions as core_exceptions
 from googlecloudsdk.core import log
 from googlecloudsdk.core import resources
 from googlecloudsdk.core import yaml
-from googlecloudsdk.core.resource import resource_projector
 from googlecloudsdk.core.resource import resource_transform
-from googlecloudsdk.core.resource import yaml_printer
 from googlecloudsdk.core.util import files
 from googlecloudsdk.core.util import times
 import six
@@ -81,82 +75,6 @@ _TIME_PATTERN = '$TIME'
 
 GENERATED_SKAFFOLD = 'skaffold.yaml'
 
-CLOUD_RUN_GENERATED_MANIFEST_TEMPLATE = """\
-apiVersion: serving.knative.dev/v1
-kind: Service
-metadata:
-  name: {service}
-spec:
-  template:
-    spec:
-      containers:
-       - image: {container}
-"""
-
-
-class TargetProperties:
-  """Stores the properies of a Target."""
-
-  def __init__(self, target_id, location):
-    # The target_id of the Target
-    self.target_id = target_id
-    # The location of the Target
-    self.location = location
-    # Every target should have a single profile.
-    # The profile associated with this target.
-    self.profile = None
-    # The manifest generated for this target.
-    self.manifest = None
-
-
-class ServicePrinter(yaml_printer.YamlPrinter):
-  """Printer for CloudRun Service objects to export.
-
-  Omits status information, and metadata that isn't consistent across
-  deployments, like project or region.
-  """
-
-  def _AddRecord(self, record, delimit=True):
-    record = self._FilterForExport(record)
-    super(ServicePrinter, self)._AddRecord(record, delimit)
-
-  def _FilterForExport(self, record):
-    new_manifest = copy.deepcopy(record)
-    if 'metadata' in new_manifest:
-      new_manifest['metadata'].pop('annotations', None)
-      new_manifest['metadata'].pop('creationTimestamp', None)
-      new_manifest['metadata'].pop('generation', None)
-      new_manifest['metadata'].pop('labels', None)
-      new_manifest['metadata'].pop('namespace', None)
-      new_manifest['metadata'].pop('resourceVersion', None)
-      new_manifest['metadata'].pop('selfLink', None)
-      new_manifest['metadata'].pop('uid', None)
-    new_manifest.get('spec', {}).get('template', {}).get('metadata', {}).pop(
-        'name', None
-    )
-    new_manifest.get('spec', {}).pop('traffic', None)
-    new_manifest.pop('status', None)
-    return new_manifest
-
-
-def _AddContainerToManifest(manifest, service_name, from_run_container):
-  """Adds a container to the manifest yaml."""
-  if (
-      len(
-          manifest.get('spec', {})
-          .get('template', {})
-          .get('spec', {})
-          .get('containers', [])
-      )
-      != 1
-  ):
-    raise core_exceptions.Error(
-        'Number of containers in service {} is not 1.'.format(service_name)
-    )
-  container_change = manifest['spec']['template']['spec']['containers'][0]
-  container_change['image'] = from_run_container
-  return manifest
-
 
 def RenderPattern(release_id):
   """Finds and replaces keywords in the release name.
@@ -245,8 +163,6 @@ def CreateReleaseConfig(
     pipeline_uuid,
     from_k8s_manifest,
     from_run_manifest,
-    from_run_container,
-    services,
     pipeline_obj,
     deploy_parameters=None,
     hide_logs=False,
@@ -256,7 +172,7 @@ def CreateReleaseConfig(
   # If either a kubernetes manifest or Cloud Run manifest was given, this means
   # a Skaffold file should be generated, so we should not check at this stage
   # if the Skaffold file exists.
-  if not (from_k8s_manifest or from_run_manifest or from_run_container):
+  if not (from_k8s_manifest or from_run_manifest):
     _VerifySkaffoldFileExists(source, skaffold_file)
   messages = client_util.GetMessagesModule(client_util.GetClientInstance())
   release_config = messages.Release()
@@ -271,8 +187,6 @@ def CreateReleaseConfig(
       pipeline_uuid,
       from_k8s_manifest,
       from_run_manifest,
-      from_run_container,
-      services,
       skaffold_file,
       pipeline_obj,
       hide_logs,
@@ -349,8 +263,6 @@ def _SetSource(
     pipeline_uuid,
     kubernetes_manifest,
     cloud_run_manifest,
-    from_run_container,
-    services,
     skaffold_file,
     pipeline_obj,
     hide_logs=False,
@@ -374,12 +286,6 @@ def _SetSource(
     cloud_run_manifest: path to Cloud Run manifest (e.g.
       /home/user/service.yaml).If provided, a Skaffold file will be generated
       and uploaded to GCS on behalf of the customer.
-    from_run_container: the container image (e.g.
-      gcr.io/google-containers/nginx@sha256:f49a843c29). If provided, a CloudRun
-      manifest file and a Skaffold file will be generated and uploaded to GCS on
-      behalf of the customer.
-    services: the map from target_id to service_name. This is present only if
-      from_run_container is not None.
     skaffold_file: path of the skaffold file relative to the source directory
       that contains the Skaffold file.
     pipeline_obj: the pipeline_obj used for this release.
@@ -455,13 +361,11 @@ def _SetSource(
     )
   else:
     # If a Skaffold file should be generated
-    if kubernetes_manifest or cloud_run_manifest or from_run_container:
+    if kubernetes_manifest or cloud_run_manifest:
       skaffold_is_generated = True
       _UploadTarballGeneratedSkaffoldAndManifest(
           kubernetes_manifest,
           cloud_run_manifest,
-          from_run_container,
-          services,
           gcs_client,
           gcs_source_staging,
           ignore_file,
@@ -548,118 +452,9 @@ def _GetTargetAndUniqueProfiles(pipeline_obj):
   return target_to_unique_profile
 
 
-def _GetRunTargetProperties(target_ids, project, location):
-  """Gets target properties for targets."""
-  target_to_target_properties = {}
-  for target_id in target_ids:
-    target_ref = target_util.TargetReference(target_id, project, location)
-    target = target_util.GetTarget(target_ref)
-    target_location = getattr(target, 'run', None)
-    if not target_location:
-      raise core_exceptions.Error('Target is not of type {}'.format('run'))
-    location_attr = getattr(target_location, 'location', None)
-    if not location_attr:
-      raise core_exceptions.Error(
-          'Target location {} does not have a location attribute.'.format(
-              target_location
-          )
-      )
-    target_to_target_properties[target_id] = TargetProperties(
-        target_id, location_attr
-    )
-  return target_to_target_properties
-
-
-def _GetRunTargetsAndProfiles(pipeline_obj):
-  """Gets targets and profiles from pipeline_obj."""
-  project = pipeline_obj.name.split('/')[1]
-  location = pipeline_obj.name.split('/')[3]
-  target_to_unique_profile = _GetTargetAndUniqueProfiles(pipeline_obj)
-  target_to_target_properties = _GetRunTargetProperties(
-      target_to_unique_profile.keys(), project, location
-  )
-  for target, profile in target_to_unique_profile.items():
-    target_to_target_properties[target].profile = profile
-  return target_to_target_properties
-
-
-def _CreateManifestsForRunContainer(
-    target_to_target_properties, services, from_run_container
-):
-  """Creates manifests for target_id to _TargetProperties object.
-
-  Args:
-    target_to_target_properties: map from target_id to _TargetProperties
-    services: map of target_id to service_name
-    from_run_container: the container to be deployed
-
-  Returns:
-    Dictionary of target_id to _TargetProperties where manifest field in
-    _TargetProperties is filled in.
-  """
-  for target_id in target_to_target_properties:
-    target_location = target_to_target_properties[target_id].location
-    region = target_location.split('/')[-1]
-    project = target_location.split('/')[1]
-    if target_id not in services:
-      raise core_exceptions.Error(
-          'Target {} has not been specified in services.'.format(target_id)
-      )
-    service_name = services[target_id]
-    service = cloudrun.ServiceExists(
-        None,
-        project=project,
-        service_name=service_name,
-        region=region,
-        release_track=base.ReleaseTrack.GA,
-    )
-    if service:
-      manifest = resource_projector.MakeSerializable(service)
-      manifest = _AddContainerToManifest(
-          manifest, service_name, from_run_container
-      )
-      stream_manifest = io.StringIO()
-      service_printer = ServicePrinter(stream_manifest)
-      service_printer.AddRecord(manifest)
-      new_manifest = stream_manifest.getvalue()
-      stream_manifest.close()
-      target_to_target_properties[target_id].manifest = new_manifest
-    else:
-      manifest_string = CLOUD_RUN_GENERATED_MANIFEST_TEMPLATE.format(
-          service=service_name, container=from_run_container
-      )
-      target_to_target_properties[target_id].manifest = manifest_string
-  return target_to_target_properties
-
-
-def _GetCloudRunManifestSkaffold(from_run_container, services, pipeline_obj):
-  """Generates a Skaffold file and a map of target_id to its manifest.
-
-  Args:
-    from_run_container: the container to be used in the new Service.
-    services: a map of target_id to service_name.
-    pipeline_obj: the pipeline object used in this release.
-
-  Returns:
-    skaffold_file: the yaml of the generated skaffold file.
-    target_to_target_properties: a map of target_id to its properties which
-      include profile, the manifest which will be used.
-  """
-  target_to_target_properties = _GetRunTargetsAndProfiles(pipeline_obj)
-  skaffold = skaffold_util.CreateSkaffoldFileForRunContainer(
-      target_to_target_properties, pipeline_obj
-  )
-  target_to_target_properties = _CreateManifestsForRunContainer(
-      target_to_target_properties, services, from_run_container
-  )
-  return skaffold, target_to_target_properties
-
-
 def _UploadTarballGeneratedSkaffoldAndManifest(
     kubernetes_manifest,
     cloud_run_manifest,
-    from_run_container,
-    services,
     gcs_client,
     gcs_source_staging,
     ignore_file,
@@ -676,11 +471,6 @@ def _UploadTarballGeneratedSkaffoldAndManifest(
     cloud_run_manifest: path to Cloud Run manifest (e.g.
       /home/user/service.yaml). If provided, a Skaffold file will be generated
       and uploaded to GCS on behalf of the customer.
-    from_run_container: the container image to be used. The Cloud Run manifest
-      and Skaffold file will be generated and uploaded to GCS on behalf of the
-      customer.
-    services: the map from target_id to service_name in case from_run_container
-      is used.
     gcs_client: client for Google Cloud Storage API.
     gcs_source_staging: directory in google cloud storage to use for staging
     ignore_file: the ignore file to use
@@ -689,52 +479,37 @@ def _UploadTarballGeneratedSkaffoldAndManifest(
     pipeline_obj: the pipeline_obj used for this release.
   """
   with files.TemporaryDirectory() as temp_dir:
-    if from_run_container:
-      skaffold, target_to_target_properties = _GetCloudRunManifestSkaffold(
-          from_run_container, services, pipeline_obj
+    manifest = ''
+    skaffold_yaml = ''
+    if kubernetes_manifest:
+      manifest = kubernetes_manifest
+      skaffold_yaml = skaffold_util.CreateSkaffoldFileForManifest(
+          pipeline_obj,
+          os.path.basename(manifest),
+          skaffold_util.GKE_GENERATED_SKAFFOLD_TEMPLATE,
       )
-      for target_id in target_to_target_properties:
-        manifest_path = os.path.join(
-            temp_dir, '{}_manifest.yaml'.format(target_id)
-        )
-        with files.FileWriter(manifest_path) as f:
-          f.write('# Auto-generated by Google Cloud Deploy\n')
-          f.write(target_to_target_properties[target_id].manifest)
-      skaffold_path = os.path.join(temp_dir, GENERATED_SKAFFOLD)
-      with files.FileWriter(skaffold_path) as f:
-        yaml.dump(skaffold, f, round_trip=True)
-    else:
-      manifest = ''
-      skaffold_yaml = ''
-      if kubernetes_manifest:
-        manifest = kubernetes_manifest
-        skaffold_yaml = skaffold_util.CreateSkaffoldFileForManifest(
-            pipeline_obj,
-            os.path.basename(manifest),
-            skaffold_util.GKE_GENERATED_SKAFFOLD_TEMPLATE,
-        )
-      elif cloud_run_manifest:
-        manifest = cloud_run_manifest
-        skaffold_yaml = skaffold_util.CreateSkaffoldFileForManifest(
-            pipeline_obj,
-            os.path.basename(manifest),
-            skaffold_util.CLOUD_RUN_GENERATED_SKAFFOLD_TEMPLATE,
-        )
-      # Check that the manifest file exists.
-      if not os.path.exists(manifest):
-        raise c_exceptions.BadFileException(
-            'could not find manifest file [{src}]'.format(src=manifest)
-        )
-      # Create the YAML data. Copying to a temp directory to avoid editing
-      # the local directory.
-      shutil.copy(manifest, temp_dir)
+    elif cloud_run_manifest:
+      manifest = cloud_run_manifest
+      skaffold_yaml = skaffold_util.CreateSkaffoldFileForManifest(
+          pipeline_obj,
+          os.path.basename(manifest),
+          skaffold_util.CLOUD_RUN_GENERATED_SKAFFOLD_TEMPLATE,
+      )
+    # Check that the manifest file exists.
+    if not os.path.exists(manifest):
+      raise c_exceptions.BadFileException(
+          'could not find manifest file [{src}]'.format(src=manifest)
+      )
+    # Create the YAML data. Copying to a temp directory to avoid editing
+    # the local directory.
+    shutil.copy(manifest, temp_dir)
 
-      skaffold_path = os.path.join(temp_dir, GENERATED_SKAFFOLD)
-      with files.FileWriter(skaffold_path) as f:
-        # Prepend the auto-generated line to the YAML file
-        f.write('# Auto-generated by Google Cloud Deploy\n')
-        # Dump the yaml data to the Skaffold file.
-        yaml.dump(skaffold_yaml, f, round_trip=True)
+    skaffold_path = os.path.join(temp_dir, GENERATED_SKAFFOLD)
+    with files.FileWriter(skaffold_path) as f:
+      # Prepend the auto-generated line to the YAML file
+      f.write('# Auto-generated by Google Cloud Deploy\n')
+      # Dump the yaml data to the Skaffold file.
+      yaml.dump(skaffold_yaml, f, round_trip=True)
     _CreateAndUploadTarball(
         gcs_client,
         gcs_source_staging,
