@@ -1109,6 +1109,9 @@ class GenerateContentResponse(proto.Message):
             tool_use_prompt_token_count (int):
                 Output only. Number of tokens present in
                 tool-use prompt(s).
+            thoughts_token_count (int):
+                Output only. Number of tokens present in
+                thoughts output.
             total_token_count (int):
                 Total token count for prompt, response
                 candidates, and tool-use prompts (if present).
@@ -1127,7 +1130,26 @@ class GenerateContentResponse(proto.Message):
             tool_use_prompt_tokens_details (MutableSequence[googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.ModalityTokenCount]):
                 Output only. List of modalities that were
                 processed for tool-use request inputs.
+            traffic_type (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.GenerateContentResponse.UsageMetadata.TrafficType):
+                Output only. Traffic type. This shows whether
+                a request consumes Pay-As-You-Go or Provisioned
+                Throughput quota.
         """
+        class TrafficType(proto.Enum):
+            r"""Request traffic type. Indicates whether the request consumes
+            Pay-As-You-Go or Provisioned Throughput quota.
+
+            Values:
+                TRAFFIC_TYPE_UNSPECIFIED (0):
+                    Unspecified request traffic type.
+                ON_DEMAND (1):
+                    Type for Pay-As-You-Go traffic.
+                PROVISIONED_THROUGHPUT (2):
+                    Type for Provisioned Throughput traffic.
+            """
+            TRAFFIC_TYPE_UNSPECIFIED = 0
+            ON_DEMAND = 1
+            PROVISIONED_THROUGHPUT = 2
 
         prompt_token_count: int = proto.Field(
             proto.INT32,
@@ -1141,6 +1163,10 @@ class GenerateContentResponse(proto.Message):
             proto.INT32,
             number=13,
         )
+        thoughts_token_count: int = proto.Field(
+            proto.INT32,
+            number=14,
+        )
         total_token_count: int = proto.Field(
             proto.INT32,
             number=3,
@@ -1169,6 +1195,11 @@ class GenerateContentResponse(proto.Message):
             number=12,
             message=content.ModalityTokenCount,
         )
+        traffic_type: 'GenerateContentResponse.UsageMetadata.TrafficType' = proto.Field(
+            proto.ENUM,
+            number=8,
+            enum='GenerateContentResponse.UsageMetadata.TrafficType',
+        )
 
     candidates: MutableSequence[content.Candidate] = proto.RepeatedField(
         proto.MESSAGE,
