@@ -81,16 +81,18 @@ class Register(base.CreateCommand):
     attached_flags.AddAdminUsers(parser)
     attached_flags.AddKubectl(parser)
     attached_flags.AddProxyConfig(parser)
+    attached_flags.AddSkipClusterAdminCheck(parser)
 
     flags.AddAnnotations(parser)
     flags.AddValidateOnly(parser, 'cluster to create')
     flags.AddFleetProject(parser)
     flags.AddDescription(parser)
     flags.AddLogging(parser, True)
-    flags.AddMonitoringConfig(parser, True)
+    flags.AddMonitoringConfig(parser, True, True)
     flags.AddBinauthzEvaluationMode(parser)
     flags.AddAdminGroups(parser)
     flags.AddWorkloadVulnerabilityScanning(parser)
+    flags.AddTagBindings(parser)
 
     parser.display_info.AddFormat(constants.ATTACHED_CLUSTERS_FORMAT)
 
@@ -113,7 +115,8 @@ class Register(base.CreateCommand):
           context=attached_flags.GetContext(args),
           enable_workload_identity=True,
       ) as kube_client:
-        kube_client.CheckClusterAdminPermissions()
+        if not attached_flags.GetSkipClusterAdminCheck(args):
+          kube_client.CheckClusterAdminPermissions()
 
         if attached_flags.GetHasPrivateIssuer(args):
           pretty_print.Info('Fetching cluster OIDC information')
