@@ -210,7 +210,10 @@ class Update(base.UpdateCommand):
         by --delete-max-age or --delete-expiration-time flags)
         """)
 
-    idle_stop_group = parser.add_mutually_exclusive_group()
+    idle_stop_group = parser.add_mutually_exclusive_group(
+        # TODO: b/368979261 - Unhide scheduled stop flags after release.
+        hidden=True,
+    )
     idle_stop_group.add_argument(
         '--stop-max-idle',
         type=arg_parsers.Duration(),
@@ -227,7 +230,10 @@ class Update(base.UpdateCommand):
         by --stop-max-idle flag)
         """)
 
-    auto_stop_group = parser.add_mutually_exclusive_group()
+    auto_stop_group = parser.add_mutually_exclusive_group(
+        # TODO: b/368979261 - Unhide scheduled stop flags after release.
+        hidden=True,
+    )
     auto_stop_group.add_argument(
         '--stop-max-age',
         type=arg_parsers.Duration(),
@@ -235,7 +241,8 @@ class Update(base.UpdateCommand):
         The lifespan of the cluster, with auto-stop upon completion,
         such as "2h" or "1d".
         See $ gcloud topic datetimes for information on duration formats.
-        """)
+        """,
+    )
     auto_stop_group.add_argument(
         '--stop-expiration-time',
         type=arg_parsers.Datetime.Parse,
