@@ -46,7 +46,6 @@ OVERRIDE_FLAGS_SET = (
     'backup_location',
     'cpu',
     'collation',
-    'database_flags',
     'enable_bin_log',
     'retained_backups_count',
     'retained_transaction_log_days',
@@ -92,6 +91,7 @@ OVERRIDE_FLAGS_SET = (
     'psc_auto_connections',
     'server_ca_mode',
     'region',
+    'retain_backups_on_delete',
 )
 
 
@@ -108,7 +108,6 @@ def AddInstanceSettingsArgs(parser):
   flags.AddBackupLocation(parser, allow_empty=False)
   flags.AddCPU(parser)
   flags.AddInstanceCollation(parser)
-  flags.AddDatabaseFlags(parser)
   flags.AddEnableBinLog(parser)
   flags.AddRetainedBackupsCount(parser)
   flags.AddRetainedTransactionLogDays(parser)
@@ -170,6 +169,7 @@ def AddInstanceSettingsArgs(parser):
   )
   flags.AddServerCaMode(parser, hidden=True)
   flags.AddTags(parser, hidden=True)
+  flags.AddRetainBackupsOnDelete(parser, hidden=True)
 
 
 def _ValidateBackupRequest(is_project_backup, args, overrides):
